#
# spec file for package emacs-jinx
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023 Björn Bidar
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _name    jinx

Name:           emacs-%{_name}
Version:        2.1
Release:        bp160.1.1
Summary:        Enchanted Spell Checker for Emacs
License:        GPL-3.0-or-later
Group:          Productivity/Text/Editors
URL:            https://github.com/minad/jinx
Source0:        %{_name}-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM Only export necessary sumbols in dynamic mod PR 106
Patch1:         0001-Only-export-necessary-symbols.-Fixes-105.patch
# PATCH-FEATURE-UPSTREAM install targets PR 102
Patch2:         0002-Add-makefile-to-build-and-install-jinx.patch
BuildRequires:  emacs-compat
BuildRequires:  emacs-devel
BuildRequires:  emacs-nox
BuildRequires:  make
BuildRequires:  pkgconfig(enchant-2)
Requires:       emacs
Requires:       emacs-compat
Supplements:    emacs

%description
Jinx is a fast just-in-time spell-checker for Emacs.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%make_build

%install
%make_install DYNMODDRIR=%{_emacs_archsitelispdir}

%check

%files
%doc README.org CHANGELOG.org
%license LICENSE
%{_emacs_sitelispdir}/%{_name}.el*
%{_emacs_sitelispdir}/%{_name}-autoloads.el
%dir %{_libdir}/emacs
%dir %{_libdir}/emacs/site-lisp/
%{_emacs_archsitelispdir}/%{_name}-mod.so

%changelog
* Thu Apr 17 2025 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase 0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 2.1
- Update to version 2.1:
  * README: Update suggested Vertico configuration
  * Offer lower-case words for saving in personal dictionary
  * Improve lighter and menu, also include correct word next
    to correct all.
  * Add ~jinx-dir-local-words~ saved in ~.dir-locals.el~.
    Words can be added to the ~.dir-locals.el~ with the ~/~ key
    in the ~jinx-correct~ dialog
  * ~jinx-correct~: For capitalized words, offer lower case variants to save in
    personal dictionary and file local variables.
  * Add ~help-echo~ to the Jinx overlays to show possibly actions
    to perform on highlighted word
* Mon Feb 10 2025 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase 0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 1.12
- Update to version 1.12:
  * Attempt to fix performance problem in folded Org buffers (gh#minad/jinx#187)
  * lisp-data-mode: Exclude symbols in docstrings
  * Use next-single-property-change when scanning for jinx--pending
  * Update README
  * Add comment regarding eager-display on Emacs 31
  * Use with-memoization, requires Emacs 29.1 or compat-29
  * Use weak hash table for loaded dictionaries
  * Preserve alist of loaded dictionaries (gh#rrthomas/enchant#402)
* Sun Jan 26 2025 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase p0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 1.11
- Update to version 1.11:
  * Add tsx-ts-mode to jinx-camel-modes (gh#minad/jinx#219)
  * Extract jinx--compile-flags (Fix gh#minad/jinx#218)
  * Remove org-fold code to improve performance in Org-mode buffers.
  * Customization group: Add link to the wiki
  * Remove with-delayed-message workaround (Emacs#63253)
  * Workaround broken :predicate keyword in Emacs 28 and older
* Sat Aug  3 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase p0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 1.10
- Update to version 1.10:
  * Add jinx--syntax-overrides to override syntax table
* Sun Jul  7 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase p0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 1.9.
- Update to version 1.9:
  * Expose (jinx-correct-all t) via C-u C-u C-u M-x jinx-correct
  * jinx-correct-all: Add ONLY-CHECK argument.
  * A better fix for gh#minad/jinx#156
  * Revert "Fix bug in jinx--find-visible-pending (See gh#minad/jinx#156)"
  * Fix bug in jinx--find-visible-pending (See gh#minad/jinx#156)
  * correct link to enchant manual (gh#minad/jinx#185)
* Wed Jun 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase p0001-Only-export-necessary-symbols.-Fixes-105.patch
  against version 1.8.
- Update to version 1.8:
  * Fix wrong-type-argument (Fix gh#minad/jinx#175)
  * README: Fix grammatical mistake
  * Ignore message-separator
  * Add jinx-save-languages
  * jinx--word-valid-p: Do not error on invalid characters (Fix gh#minad/jinx#93, gh#minad/jinx#164)
* Sat Apr 13 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase 0001-Only-export-necessary-symbols.-Fixes-105.patch against
  1.6
- Update to version 1.6:
  * Fix jinx-mode reentrancy issue #gh/minad/jinx#158
  * Ensure that directory local variables work correctly with Jinx.
    It is possible to turn Jinx on or off via dir-locals,
    and also configure the language and local words.
  * jinx-mod: Add global ref Qcons
  * jinx-next: Unfold hidden misspelling
* Mon Mar 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 1.4:
  * Update README
  * Fix: Ensure that `eval' local variable enabling `jinx-mode' works
  * yaml-mode/yaml-ts-mode: Alias to conf-mode
  * Remove TeX-mode alias
  * jinx-exclude/include-faces, jinx-exclude-regexps: Support mode aliases
  * jinx-correct-all: Restrict corrections to marked region
  * jinx-correct: Ensure that word is saved without text properties (Fix gh#minad/jinx#140)
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Depend on emacs-devel to make sure Emacs packaging macros are installed when not building with emacs-eln
* Mon Feb 26 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 1.3:
  * jinx-mode: hack-local-variables - ignore mode variables
  * README: List packages needed on OpenSUSE
  * Fix interaction bug with the newest version of AUCTeX, where the major mode
    got changed unexpectedly.
  * No need to use hashed symbol as argument for derived-mode-p
  * Fix deadlock on macOS during Jinx startup (Fix gh#minad/jinx#91, gh#minad/jinx#113)
  * Revert "Simplify rescheduling"
  * timer-activate-when-idle: Pass DONT-WAIT=t
* Wed Jan 31 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Rebase patches and remove those no longer required
- Update to version 1.2:
  * Fix deadlock on macOS during Jinx startup (Fix gh#minad/jinx#91, gh#minad/jinx#113)
  * Revert "Simplify rescheduling"
  * timer-activate-when-idle: Pass DONT-WAIT=t
  * jinx--base-syntax-table: Exclude private use areas
  * Bump copyright years
  * Replace keyword wp with text
  * Reschedule on window selection change
  * Simplify rescheduling
  * Avoid a little bit of timer consing
  * Use menu-item for mouse menu
  * Use hashed symbols
  * Add jinx-menu-suggestions defcustom
  * More compact mouse menu, delete duplicates
  * jinx-correct-menu: Use jinx-correct-word
  * Add mouse context menu
  * New function jinx--session-suggestions
  * jinx-mode: Extract jinx--reschedule-hooks variable
  * derived-mode-p: Calling convention change
  * Handle LANG=C or LANG=POSIX environment variables (Fix gh#minad/jinx#116)
  * Fix some package-lint warnings
  * Revert "jinx-correct: Setup minibuffer keymaps later (Fix gh#minad/jinx#112)"
  * jinx-correct: Setup minibuffer keymaps later (Fix gh#minad/jinx#112)
  * Module initialization: Print a message for outdated Enchant (Fix gh#minad/jinx#111)
  * Require libenchant 2.3.1 or newer
  * Exclude Gnus cite faces inside message mode
  * jinx-mode: Support disabling via file-local variable
  * Update face list
  * Exclude cite faces inside message mode (gh#minad/jinx#108)
  * README: Mention NixOS
  * Update jinx-exclude-regexps
  * Update Org exclude faces
  * Update Org excluded faces, add org-drawer (Fix gh#minad/jinx#99)
  * Use quotes in comment
  * Fix docstring
  * Improve jinx-correct docstring
  * Rename jinx-correct-at-point to jinx-correct-word
  * jinx-correct-*: Code cleanup
  * Improve jinx-correct-at-point
  * Code cleanup, use save-excursion
  * jinx-correct: Add dispatching to jinx-correct-at-point
  * Implement jinx-correct-at-point by faking an overlay (gh#minad/jinx#89)
  * Use without-restriction
  * jinx-correct: Add prefix keys to session word suggestions (See gh#minad/jinx#96, gh#minad/jinx#97)
  * jinx-correct: Suggestion from session words (Fix gh#minad/jinx#97)
  * Remove unused variable
  * Fix condition
  * Replace jinx-include-modes with global-jinx-modes
  * jinx--word-valid-p: Simplify
  * jinx--word-valid-p: More restrictive check of capitalized words
  * jinx--word-valid-p: Allow capitalized words (See gh#minad/jinx#96)
  * Simplify jinx-correct
  * jinx-correct: Refontify should not be necessary
  * jinx-languages: Ensure that jinx-mode is enabled
  * jinx-next/previous: Add command-modes
  * jinx-exclude-regexps: Ignore hyphens used as bullet points (Fix gh#minad/jinx#87)
* Sun Oct  1 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Add patch to exclude cite faces in message mode
* Fri Sep 29 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Add patch to only export necessary symbols in jinx-mod.so
* Wed Sep 27 2023 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for OpenSuSE
- Jinx 0.9
  * 🪄 Make sure that Emojis are not marked as misspelled 🧙🏼‍♀️
  * Rename =jinx-correct-next/previous= to =jinx-next/previous=. The commands can be
    used outside the minibuffer
  * Bind =M-n= and =M-p= to =jinx-next/previous= in =jinx-overlay-map=
  * Bind =M-$= to =jinx-correct= in the =jinx-overlay-map=
  * Add =jinx-repeat-map=
  * Rename category of Jinx overlays to =jinx-overlay=
  * Rename =jinx-misspelled-map= to =jinx-overlay-map=
  * Add many more language modes to =jinx-camel-modes=
